@@ -12,8 +12,8 @@ setuptools.setup(
     author="Anton La Fontaine, Lukas Lehnert",
     author_email="a01351415@unet.univie.ac.at",
     ## <MAJOR_VERSION>, <MINOR_VERSION>, <MAINTENANCE_VERSION>
-    version='0.1.0',
-    description="A python client library used to show the dependency between the different libraries of g09_CPS_relocation.",
+    version='1.0.0',
+    description="A python client library used to get a quick overview between the different libraries of g09_CPS_relocation.",
     long_description=long_description,
     long_description_content_type="text/markdown",
     url='https://gitlab.dke.univie.ac.at/edu-semtech/semtec_ws2020/g09_cps_relocation',
